VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
END
Attribute VB_Name = "clsDownload"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = True
Option Explicit

' Declare object variables using the WithEvents declaration to hold a pointer
' to the FTPCopy and FTPGetFileName forms that allows receipt of custom
' events fired by the form.
Private WithEvents frmCopy As frmFTPCopy
Attribute frmCopy.VB_VarHelpID = -1
Private WithEvents frmDir As frmFTPGetFileName
Attribute frmDir.VB_VarHelpID = -1

' These events are fired to the user(s) of the FTPDownload class.
Public Event CopyComplete()
Public Event CopyCancelled()
Public Event CopyError(ByVal respCode As Integer, ByVal respInfo As String)
Public Event GetFileCompleted(ByVal sFileName As String)
Public Event GetFileCancelled()
Public Event GetFileError(ByVal respCode As Integer, _
                          ByVal respInfo As String)


' This method begins the FTP downloading process.
Public Function Copy(ByVal URL As String, ByVal Source As String, _
                     ByVal Dest As String) As Boolean
  If Not ValidDestinationPath(Dest) Then
    ' Because we are being called directly by the client, we can
    ' simply raise an error back to that client rather than raising
    ' an event.
    Err.Raise Number:=1 + vbObjectError, _
      Description:="Destination path specified is not valid"
    Exit Function
  End If
  
  FixURL URL
  Copy = frmCopy.BeginCopy(URL, Source, Dest)
End Function

Private Sub Class_Initialize()
  Set frmCopy = New frmFTPCopy
  Set frmDir = New frmFTPGetFileName
End Sub

Private Sub frmCopy_CopyCancelled()
  RaiseEvent CopyCancelled
End Sub

Private Sub frmCopy_CopyCompleted()
  RaiseEvent CopyComplete
End Sub

Private Sub frmCopy_CopyError(ByVal respCode As Integer, ByVal respInfo As String)
  RaiseEvent CopyError(respCode, respInfo)
End Sub

Private Function ValidDestinationPath(ByVal Dest As String) As Boolean
  ' Test that the destination specified is a valid directory.
  Dim path As String
  Dim pos As Integer
  
  ValidDestinationPath = True
  
  ' Find the last '\' in the destination
  For pos = Len(Dest) To 1 Step -1
    If Mid$(Dest, pos, 1) = "\" Then
      path = Left$(Dest, pos)
      Exit For
    End If
  Next pos
  
  ' Note that a zero-length path assumes the current directory, which
  ' is always valid.
  If Len(path) > 0 Then
    ValidDestinationPath = (Len(Dir$(path, vbDirectory)) > 0)
  End If
End Function

Private Sub frmDir_FileGetCancelled()
  RaiseEvent GetFileCancelled
End Sub

Private Sub frmDir_FileGetCompleted(ByVal sFileName As String)
  RaiseEvent GetFileCompleted(sFileName)
End Sub

Private Sub frmDir_FileGetError(ByVal respCode As Integer, _
                                ByVal respInfo As String)
  RaiseEvent GetFileError(respCode, respInfo)
End Sub

Public Sub GetFileName(ByVal URL As String)
  FixURL URL
  frmDir.BeginGetFile URL
End Sub

Private Sub FixURL(ByRef URL As String)
  If UCase$(Left$(URL, 6)) <> "FTP://" Then
    URL = "ftp://" & URL
  End If
End Sub
